@@ -186,6 +186,7 @@ import org.kde.kcmutils as KCMUtils
 Kirigami.ApplicationItem {
     // force it to *never* try to resize itself
     width: Window.width
+    height: Window.height
 
     implicitWidth: Math.max(pageStack.implicitWidth, Kirigami.Units.gridUnit * 36)
     implicitHeight: Math.max(pageStack.implicitHeight, Kirigami.Units.gridUnit * 20)
@@ -201,7 +202,6 @@ Kirigami.ApplicationItem {
     }
 
     pageStack.separatorVisible: pageStack.depth > 0 && (pageStack.items[0].sidebarMode ?? false)
-    pageStack.globalToolBar.preferredHeight: toolButton.implicitHeight + Kirigami.Units.smallSpacing * 2
     pageStack.globalToolBar.style: Kirigami.ApplicationHeaderStyle.ToolBar
     pageStack.globalToolBar.showNavigationButtons: Kirigami.ApplicationHeaderStyle.ShowBackButton
 
